==> zio-aws-managedblockchain_2.12-5.19.8.4-sources.jar: zio/aws/managedblockchain/model/Accessor.scala <==
package zio.aws.managedblockchain.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.managedblockchain.model.primitives.{
  ArnString,
  Timestamp,
  AccessorBillingTokenString,
  ResourceIdString
}
import scala.jdk.CollectionConverters._
final case class Accessor(
    id: Optional[ResourceIdString] = Optional.Absent,
    `type`: Optional[zio.aws.managedblockchain.model.AccessorType] =
      Optional.Absent,
    billingToken: Optional[AccessorBillingTokenString] = Optional.Absent,
    status: Optional[zio.aws.managedblockchain.model.AccessorStatus] =
      Optional.Absent,
    creationDate: Optional[Timestamp] = Optional.Absent,
    arn: Optional[ArnString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.managedblockchain.model.Accessor = {
    import Accessor.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.managedblockchain.model.Accessor
      .builder()
      .optionallyWith(
        id.map(value => ResourceIdString.unwrap(value): java.lang.String)
      )(_.id)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(
        billingToken.map(value =>
          AccessorBillingTokenString.unwrap(value): java.lang.String
        )
      )(_.billingToken)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        creationDate.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationDate)
      .optionallyWith(
        arn.map(value => ArnString.unwrap(value): java.lang.String)
      )(_.arn)
      .build()
  }
  def asReadOnly: zio.aws.managedblockchain.model.Accessor.ReadOnly =
    zio.aws.managedblockchain.model.Accessor.wrap(buildAwsValue())
}
object Accessor {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.managedblockchain.model.Accessor
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.managedblockchain.model.Accessor =
      zio.aws.managedblockchain.model.Accessor(
        id.map(value => value),
        `type`.map(value => value),
        billingToken.map(value => value),
        status.map(value => value),
        creationDate.map(value => value),
        arn.map(value => value)
      )
    def id: Optional[ResourceIdString]
    def `type`: Optional[zio.aws.managedblockchain.model.AccessorType]
    def billingToken: Optional[AccessorBillingTokenString]
    def status: Optional[zio.aws.managedblockchain.model.AccessorStatus]
    def creationDate: Optional[Timestamp]
    def arn: Optional[ArnString]
    def getId: ZIO[Any, AwsError, ResourceIdString] =
      AwsError.unwrapOptionField("id", id)
    def getType
        : ZIO[Any, AwsError, zio.aws.managedblockchain.model.AccessorType] =
      AwsError.unwrapOptionField("type", `type`)
    def getBillingToken: ZIO[Any, AwsError, AccessorBillingTokenString] =
      AwsError.unwrapOptionField("billingToken", billingToken)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.managedblockchain.model.AccessorStatus] =
      AwsError.unwrapOptionField("status", status)
    def getCreationDate: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationDate", creationDate)
    def getArn: ZIO[Any, AwsError, ArnString] =
      AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.managedblockchain.model.Accessor
  ) extends zio.aws.managedblockchain.model.Accessor.ReadOnly {
    override val id: Optional[ResourceIdString] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value =>
        zio.aws.managedblockchain.model.primitives.ResourceIdString(value)
      )
    override val `type`
        : Optional[zio.aws.managedblockchain.model.AccessorType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.managedblockchain.model.AccessorType.wrap(value))
    override val billingToken: Optional[AccessorBillingTokenString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.billingToken())
        .map(value =>
          zio.aws.managedblockchain.model.primitives
            .AccessorBillingTokenString(value)
        )
    override val status
        : Optional[zio.aws.managedblockchain.model.AccessorStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.managedblockchain.model.AccessorStatus.wrap(value)
        )
    override val creationDate: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationDate())
      .map(value => zio.aws.managedblockchain.model.primitives.Timestamp(value))
    override val arn: Optional[ArnString] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.managedblockchain.model.primitives.ArnString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.managedblockchain.model.Accessor
  ): zio.aws.managedblockchain.model.Accessor.ReadOnly = new Wrapper(impl)
}

==> zio-aws-managedblockchain_2.13-6.20.74.2-sources.jar: zio/aws/managedblockchain/model/Accessor.scala <==
package zio.aws.managedblockchain.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.managedblockchain.model.primitives.{
  Timestamp,
  TagValue,
  ResourceIdString,
  AccessorBillingTokenString,
  ArnString,
  TagKey
}
import scala.jdk.CollectionConverters._
final case class Accessor(
    id: Optional[ResourceIdString] = Optional.Absent,
    `type`: Optional[zio.aws.managedblockchain.model.AccessorType] =
      Optional.Absent,
    billingToken: Optional[AccessorBillingTokenString] = Optional.Absent,
    status: Optional[zio.aws.managedblockchain.model.AccessorStatus] =
      Optional.Absent,
    creationDate: Optional[Timestamp] = Optional.Absent,
    arn: Optional[ArnString] = Optional.Absent,
    tags: Optional[Map[TagKey, TagValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.managedblockchain.model.Accessor = {
    import Accessor.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.managedblockchain.model.Accessor
      .builder()
      .optionallyWith(
        id.map(value => ResourceIdString.unwrap(value): java.lang.String)
      )(_.id)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(
        billingToken.map(value =>
          AccessorBillingTokenString.unwrap(value): java.lang.String
        )
      )(_.billingToken)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        creationDate.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationDate)
      .optionallyWith(
        arn.map(value => ArnString.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.managedblockchain.model.Accessor.ReadOnly =
    zio.aws.managedblockchain.model.Accessor.wrap(buildAwsValue())
}
object Accessor {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.managedblockchain.model.Accessor
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.managedblockchain.model.Accessor =
      zio.aws.managedblockchain.model.Accessor(
        id.map(value => value),
        `type`.map(value => value),
        billingToken.map(value => value),
        status.map(value => value),
        creationDate.map(value => value),
        arn.map(value => value),
        tags.map(value => value)
      )
    def id: Optional[ResourceIdString]
    def `type`: Optional[zio.aws.managedblockchain.model.AccessorType]
    def billingToken: Optional[AccessorBillingTokenString]
    def status: Optional[zio.aws.managedblockchain.model.AccessorStatus]
    def creationDate: Optional[Timestamp]
    def arn: Optional[ArnString]
    def tags: Optional[Map[TagKey, TagValue]]
    def getId: ZIO[Any, AwsError, ResourceIdString] =
      AwsError.unwrapOptionField("id", id)
    def getType
        : ZIO[Any, AwsError, zio.aws.managedblockchain.model.AccessorType] =
      AwsError.unwrapOptionField("type", `type`)
    def getBillingToken: ZIO[Any, AwsError, AccessorBillingTokenString] =
      AwsError.unwrapOptionField("billingToken", billingToken)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.managedblockchain.model.AccessorStatus] =
      AwsError.unwrapOptionField("status", status)
    def getCreationDate: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationDate", creationDate)
    def getArn: ZIO[Any, AwsError, ArnString] =
      AwsError.unwrapOptionField("arn", arn)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.managedblockchain.model.Accessor
  ) extends zio.aws.managedblockchain.model.Accessor.ReadOnly {
    override val id: Optional[ResourceIdString] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value =>
        zio.aws.managedblockchain.model.primitives.ResourceIdString(value)
      )
    override val `type`
        : Optional[zio.aws.managedblockchain.model.AccessorType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.managedblockchain.model.AccessorType.wrap(value))
    override val billingToken: Optional[AccessorBillingTokenString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.billingToken())
        .map(value =>
          zio.aws.managedblockchain.model.primitives
            .AccessorBillingTokenString(value)
        )
    override val status
        : Optional[zio.aws.managedblockchain.model.AccessorStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.managedblockchain.model.AccessorStatus.wrap(value)
        )
    override val creationDate: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationDate())
      .map(value => zio.aws.managedblockchain.model.primitives.Timestamp(value))
    override val arn: Optional[ArnString] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.managedblockchain.model.primitives.ArnString(value))
    override val tags: Optional[Map[TagKey, TagValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.managedblockchain.model.primitives.TagKey(
              key
            ) -> zio.aws.managedblockchain.model.primitives.TagValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.managedblockchain.model.Accessor
  ): zio.aws.managedblockchain.model.Accessor.ReadOnly = new Wrapper(impl)
}
